######################################################################################
######################################################################################

# Parent E. and Rivot E. - An introduction to Hierarchcial Modeling of Ecological Data
# Chapman et al.
# 2012

# R program for the Successive Removal example
# Chapter 4 - section 4.2

######################################################################################
######################################################################################

rm(list=ls()) 	
library("BRugs") 	
library(MASS)

# Load/check model, load data and inits

model <-  "model_BetaBin_SuccRem.txt"
data <-   "data_BetaBin_SuccRem.txt"
inits1 <- "inits1_BetaBin_SuccRem.txt"
inits2 <- "inits2_BetaBin_SuccRem.txt"
inits3 <- "inits3_BetaBin_SuccRem.txt"


modelCheck(model) 					# Check the model
modelData(data) 					# Load the data
modelCompile(numChains=3) 			# Compile the model with 3 chains
modelInits(c(inits1, inits2, inits3)) 	# Load the three initialisations 


# MCMC iterations

Nb_i <- 10000 		# Number of iterations for Burn in
N <- 10000 		# Number of iterations to be considered for inference
thin <- 10


# Burn-in period

modelUpdate(Nb_i, thin = thin)


# Inferences
# Set the quantities we are interested in and run N iterations

samplesSet(c("pi", "nu", "d", "d_p"))

modelUpdate(N, thin = thin) 		


# -------------------------------------------------------------------------
# Results
# -------------------------------------------------------------------------

# Have a look on posterior statistics

samplesStats("*") 

# Have a look on MCMC chains

windows()
Results <- samplesHistory("*", mfrow = c(2, 2))



# -------------------------------------------------------------------------
# Draw posterior density
# -------------------------------------------------------------------------


# Draw marginal posterior density
# -------------------------------

windows()
par(mfrow = c(2,2))

pi <- samplesSample("pi")
plot(x=0, y=-1, ylim = c(0,max(density(pi)$y)*1.1), xlim = c(0,1), ylab = "", xlab = expression(pi), main = expression(paste("Posterior pdf of ",pi)))
lines(density(pi), col = "red")

d <- samplesSample("d")
plot(x=0, y=-1, ylim = c(0,max(density(d)$y)*1.1), xlim = c(0,max(d)*1.1), ylab = "", xlab = "d", main = "Posterior pdf of d")
lines(density(d), col = "red")

nu <- samplesSample("nu")
plot(x=0, y=-1, ylim = c(0,max(density(nu)$y)*1.1), xlim = c(0,max(nu)*1.1), ylab = "", xlab = expression(nu), main = expression(paste("Posterior pdf of ",nu)))
lines(density(nu), col = "red")



# Joint posterior distribution for (theta,nu)
# ---------------------------------------

def.par <- par(no.readonly = TRUE) 		# save default, for resetting...

# windows()

res <- 6
name_figure <- "JointPosteriorSuccRemov.png"
png(filename = name_figure, height = 500*res, width = 500*res, res=72*res)

x <- samplesSample("nu")
y <- samplesSample("pi")

indice <- which(x<=quantile(x, prob = 0.98))
x <- x[indice]
y <- y[indice]

xrange <- range(x) ; nbreaks.x=80
yrange <- range(y) ; nbreaks.y=100
nb.points = 2000

xhist <- hist(x, breaks=seq(xrange[1],xrange[2],length.out=nbreaks.x), plot=FALSE)
yhist <- hist(y, breaks=seq(yrange[1],yrange[2],length.out=nbreaks.y), plot=FALSE)

nf <- layout(matrix(c(2,0,1,3),2,2,byrow=TRUE), c(3,1), c(1,3), TRUE)
layout.show(nf)

par(mar=c(5,5,1,1))
plot( x[1:nb.points], y[1:nb.points], xlim=xrange, ylim=yrange, 
	xlab="", ylab="", pch=".", cex.lab = 1.3)
dens2d <- kde2d(x=x, y=y, n = 100)
contour(dens2d , nlevels = 4, drawlabels=F, col = "black", lw = 2, add = T) 

mtext(text=expression(nu), side=1, line=3, cex=1.3)
mtext(text=expression(pi), side=2, line=3, cex=1.3)

par(mar=c(0,5,3,1))
barplot(xhist$density, axes=FALSE, space=0, horiz=FALSE, col = "lightgrey")
mtext(text=expression(paste("Marginal posterior of ",nu)), side=3, line=1, cex=1.3)

par(mar=c(5,0,1,3))
barplot(yhist$density, axes=FALSE, space=0, horiz=TRUE, col = "lightgrey")
mtext(text=expression(paste("Marginal posterior of ",pi)), side=4, line = 1, las = 3, cex=1.3)

par(def.par)

dev.off()
